@@ -22,30 +22,22 @@ session. This can be done with one of the following functions:
     fastf1.get_event_schedule
 
 
-Caching
--------
+.. _requests-and-caching:
 
-Caching should almost always be enabled to speed up the runtime of your
-scripts and to prevent exceeding the rate limit of api servers.
-FastF1 will print an annoyingly obnoxious warning message if you do not
-enable caching.
+Requests and Caching
+--------------------
 
-The following class-level functions are used to setup, enable and
-(temporarily) disable caching.
+.. automodule::
+    fastf1.req
 
-.. autosummary::
-    fastf1.Cache.enable_cache
-    fastf1.Cache.clear_cache
-    fastf1.Cache.disabled
-    fastf1.Cache.set_disabled
-    fastf1.Cache.set_enabled
+.. currentmodule:: fastf1
 
 
 General Functions - API Reference
 ---------------------------------
 
-Events API
-..........
+Event and Session API
+.....................
 
 .. autofunction:: get_session
 .. autofunction:: get_testing_session
@@ -58,10 +50,37 @@ Cache API
 .........
 
 .. autoclass:: Cache
-    :members: enable_cache, clear_cache, disabled, set_disabled, set_enabled
+    :members: enable_cache, clear_cache, disabled, set_disabled, set_enabled,
+        offline_mode
     :autosummary:
 
+
+Configure Logging Verbosity
+...........................
+
+All parts of FastF1 generally log at the log level 'INFO'.
+The reason for this is that many data loading processes take multiple
+seconds to complete. Logging is used to give progress information here as well
+as for showing warnings and non-terminal errors.
+
+The logging level for FastF1 can be easily customized::
+
+    import fastf1
+
+    fastf1.set_log_level('WARNING')
+
+    # ... your code  here ... #
+
+The available levels are (in order of increasing severity): DEBUG, INFO,
+WARNING, ERROR and CRITICAL.
+
+.. autofunction:: set_log_level
+
+For more information see :ref:`logging`.
+
 """
+from typing import Dict
+
 from fastf1.events import (get_session,  # noqa: F401
                            get_testing_session,
                            get_event,
@@ -69,11 +88,13 @@ from fastf1.events import (get_session,  # noqa: F401
                            get_testing_event,
                            get_event_schedule)
 
-from fastf1.api import Cache  # noqa: F401
+from fastf1.logger import set_log_level  # noqa: F401
+
+from fastf1.req import Cache, RateLimitExceededError   # noqa: F401
 from fastf1.version import __version__   # noqa: F401
 
 
-_DRIVER_TEAM_MAPPING = {
+_DRIVER_TEAM_MAPPING: Dict[str, Dict[str, str]] = {
     # only necessary when loading live timing data that does not include
     # the driver and team listing and no data is available on ergast yet
     '23': {'Abbreviation': 'ALB', 'FirstName': 'Alexander',
