@@ -1,7 +1,4 @@
 """
-Plotting - :mod:`fastf1.plotting`
-=================================
-
 Helper functions for creating data plots.
 
 :mod:`fastf1.plotting` provides optional functionality with the intention of making
@@ -24,7 +21,7 @@ and colors which are provided below.
 .. note:: Plotting related functionality is likely to change in a future
     release.
 """
-from typing import Dict
+from typing import Dict, List
 
 import pandas as pd
 import numpy as np
@@ -45,6 +42,7 @@ except ImportError:
                   UserWarning)
 
 import warnings
+
 with warnings.catch_warnings():
     warnings.filterwarnings('ignore', message="Using slow pure-python SequenceMatcher")
     # suppress that warning, it's confusing at best here, we don't need fast sequence matching
@@ -55,6 +53,7 @@ with warnings.catch_warnings():
 class __TeamColorsWarnDict(dict):
     """Implements userwarning on KeyError in :any:`TEAM_COLORS` after
     changing team names."""
+
     def get(self, key, default=None):
         value = super().get(key, default)
         if value is None:
@@ -85,50 +84,50 @@ TEAM_COLORS = __TeamColorsWarnDict({
     'alfa romeo': '#900000', 'alphatauri': '#2b4562',
     'haas': '#ffffff', 'williams': '#005aff'
 })
-"""Mapping of team colors (hex color code) to team names.
+"""Mapping of team names to team colors (hex color codes).
 (current season only)"""
 
-
-TEAM_TRANSLATE = {'MER': 'mercedes', 'FER': 'ferrari',
-                  'RBR': 'red bull', 'MCL': 'mclaren',
-                  'APN': 'alpine', 'AMR': 'aston martin',
-                  'ARR': 'alfa romeo', 'APT': 'alphatauri',
-                  'HAA': 'haas', 'WIL': 'williams'}
+TEAM_TRANSLATE: Dict[str, str] = {
+    'MER': 'mercedes', 'FER': 'ferrari',
+    'RBR': 'red bull', 'MCL': 'mclaren',
+    'APN': 'alpine', 'AMR': 'aston martin',
+    'ARR': 'alfa romeo', 'APT': 'alphatauri',
+    'HAA': 'haas', 'WIL': 'williams'}
 """Mapping of team names to theirs respective abbreviations."""
 
-DRIVER_COLORS = {
-        "valtteri bottas": "#900000",
-        "zhou guanyu": "#500000",
+DRIVER_COLORS: Dict[str, str] = {
+    "valtteri bottas": "#900000",
+    "zhou guanyu": "#500000",
 
-        "nyck de vries": "#2b4562",
-        "yuki tsunoda": "#356cac",
+    "nyck de vries": "#2b4562",
+    "yuki tsunoda": "#356cac",
 
-        "pierre gasly": "#0090ff",
-        "esteban ocon": "#70c2ff",
+    "pierre gasly": "#0090ff",
+    "esteban ocon": "#70c2ff",
 
-        "fernando alonso": "#006f62",
-        "lance stroll": "#25a617",
-        "felipe drugovich": "#2f9b90",
+    "fernando alonso": "#006f62",
+    "lance stroll": "#25a617",
+    "felipe drugovich": "#2f9b90",
 
-        "charles leclerc": "#dc0000",
-        "carlos sainz": "#ff8181",
+    "charles leclerc": "#dc0000",
+    "carlos sainz": "#ff8181",
 
-        "kevin magnussen": "#ffffff",
-        "nico hulkenburg": "#cacaca",
+    "kevin magnussen": "#ffffff",
+    "nico hulkenberg": "#cacaca",
 
-        "oscar piastri": "#ff8700",
-        "lando norris": "#eeb370",
+    "oscar piastri": "#ff8700",
+    "lando norris": "#eeb370",
 
-        "lewis hamilton": "#00d2be",
-        "george russell": "#24ffff",
+    "lewis hamilton": "#00d2be",
+    "george russell": "#24ffff",
 
-        "max verstappen": "#0600ef",
-        "sergio perez": "#716de2",
+    "max verstappen": "#0600ef",
+    "sergio perez": "#716de2",
 
-        "alexander albon": "#005aff",
-        "logan sargeant": "#012564",
+    "alexander albon": "#005aff",
+    "logan sargeant": "#012564",
 }
-"""Mapping of driver colors (hex color code) to driver names.
+"""Mapping of driver names to driver colors (hex color codes).
 (current season only)"""
 
 DRIVER_TRANSLATE: Dict[str, str] = {
@@ -138,20 +137,32 @@ DRIVER_TRANSLATE: Dict[str, str] = {
     'GAS': 'pierre gasly', 'OCO': 'esteban ocon',
     'BOT': 'valtteri bottas', 'ZHO': 'zhou guanyu',
     'DEV': 'nyck de vries', 'TSU': 'yuki tsunoda',
-    'MAG': 'kevin magnussen', 'HUL': 'nico hulkenburg',
+    'MAG': 'kevin magnussen', 'HUL': 'nico hulkenberg',
     'ALO': 'fernando alonso', 'STR': 'lance stroll', 'DRU': 'felipe drugovich',
     'HAM': 'lewis hamilton', 'RUS': 'george russell',
     'ALB': 'alexander albon', 'SAR': 'logan sargeant'}
 """Mapping of driver names to theirs respective abbreviations."""
 
-COLOR_PALETTE = ['#FF79C6', '#50FA7B', '#8BE9FD', '#BD93F9',
-                 '#FFB86C', '#FF5555', '#F1FA8C']
+COMPOUND_COLORS: Dict[str, str] = {
+    "SOFT": "da291c",
+    "MEDIUM": "ffd12e",
+    "HARD": "f0f0ec",
+    "INTERMEDIATE": "43b02a",
+    "WET": "0067ad",
+    "UNKNOWN": "00ffff",
+}
+"""Mapping of tyre compound names to compound colors (hex color codes).
+(current season only)"""
+
+COLOR_PALETTE: List[str] = ['#FF79C6', '#50FA7B', '#8BE9FD', '#BD93F9',
+                            '#FFB86C', '#FF5555', '#F1FA8C']
 """The default color palette for matplotlib plot lines in fastf1's color
 scheme."""
 
 
-def setup_mpl(mpl_timedelta_support=True, color_scheme='fastf1',
-              misc_mpl_mods=True):
+def setup_mpl(
+        mpl_timedelta_support: bool = True, color_scheme: str = 'fastf1',
+        misc_mpl_mods: bool = True):
     """Setup matplotlib for use with fastf1.
 
     This is optional but, at least partly, highly recommended.
@@ -188,7 +199,7 @@ def setup_mpl(mpl_timedelta_support=True, color_scheme='fastf1',
         _enable_misc_mpl_mods()
 
 
-def driver_color(identifier):
+def driver_color(identifier: str) -> str:
     """Get a driver's color from a driver name or abbreviation.
 
     This function will try to find a matching driver for any identifier string
@@ -246,7 +257,8 @@ def driver_color(identifier):
             ratio = fuzz.ratio(identifier, existing_key)
             key_ratios.append((ratio, existing_key))
         key_ratios.sort(reverse=True)
-        if (key_ratios[0][0] < 35) or (key_ratios[0][0]/key_ratios[1][0] < 1.2):
+        if ((key_ratios[0][0] < 35)
+                or (key_ratios[0][0] / key_ratios[1][0] < 1.2)):
             # ensure that the best match has a minimum accuracy (35 out of
             # 100) and that it has a minimum confidence (at least 20% better
             # than second best)
@@ -255,7 +267,7 @@ def driver_color(identifier):
         return DRIVER_COLORS[best_matched_key]
 
 
-def team_color(identifier):
+def team_color(identifier: str) -> str:
     """Get a team's color from a team name or abbreviation.
 
     This function will try to find a matching team for any identifier string
@@ -319,7 +331,8 @@ def team_color(identifier):
             ratio = fuzz.ratio(identifier, existing_key)
             key_ratios.append((ratio, existing_key))
         key_ratios.sort(reverse=True)
-        if (key_ratios[0][0] < 35) or (key_ratios[0][0]/key_ratios[1][0] < 1.2):
+        if ((key_ratios[0][0] < 35)
+                or (key_ratios[0][0] / key_ratios[1][0] < 1.2)):
             # ensure that the best match has a minimum accuracy (35 out of
             # 100) and that it has a minimum confidence (at least 20% better
             # than second best)
@@ -385,6 +398,7 @@ def _enable_misc_mpl_mods():
                         kwargs[key] = [kwargs[key][i] for i in _ids]
                 kwargs.pop('sort', None)
             return bar(*args, **kwargs)
+
         return _bar_sorted_decorator
 
     plt.bar = _bar_sorted(plt.bar)
