@@ -1,19 +1,28 @@
-"""
-Utils module - :mod:`fastf1.utils`
-==================================
-"""
-import warnings
+"""This is a collection of various functions."""
+import datetime
 from functools import reduce
+from typing import Dict, Tuple, Optional
+import warnings
 
 import numpy as np
-from datetime import datetime, timedelta
+import pandas as pd
+
+from fastf1.logger import get_logger
 
 
-def delta_time(reference_lap, compare_lap):
-    # TODO move somewhere else
+_logger = get_logger(__name__)
+
+
+def delta_time(reference_lap: pd.Series, compare_lap: pd.Series) -> Tuple:
     """Calculates the delta time of a given lap, along the 'Distance' axis
     of the reference lap.
 
+    .. deprecated:: 3.0.0
+
+    .. warning:: This function should no longer be considered as a stable part
+        of the API. Due to the reasons given below, this function will be
+        modified or removed at a future point.
+
     .. warning:: This is a nice gimmick but not actually very accurate which
         is an inherent problem from the way this is calculated currently (There
         may not be a better way though). In comparison with the sector times and the
@@ -69,6 +78,11 @@ def delta_time(reference_lap, compare_lap):
           telemetry data that was created with the same interpolation and
           resampling options!
     """
+    warnings.warn("`utils.delta_time` is considered deprecated and will"
+                  "be modified or removed in a future release because it has"
+                  "a tendency to give inaccurate results.",
+                  FutureWarning)
+
     ref = reference_lap.get_car_data(interpolate_edges=True).add_distance()
     comp = compare_lap.get_car_data(interpolate_edges=True).add_distance()
 
@@ -87,7 +101,7 @@ def delta_time(reference_lap, compare_lap):
     return delta, ref, comp
 
 
-def recursive_dict_get(d, *keys, default_none=False):
+def recursive_dict_get(d: Dict, *keys: str, default_none: bool = False):
     """Recursive dict get. Can take an arbitrary number of keys and returns an empty
     dict if any key does not exist.
     https://stackoverflow.com/a/28225747"""
@@ -98,7 +112,7 @@ def recursive_dict_get(d, *keys, default_none=False):
         return ret
 
 
-def to_timedelta(x):
+def to_timedelta(x: str) -> Optional[datetime.timedelta]:
     """Fast timedelta object creation from a time string
 
     Permissible string formats:
@@ -140,20 +154,24 @@ def to_timedelta(x):
             else:
                 msus = 0
 
-            return timedelta(hours=int(hours), minutes=int(minutes),
-                             seconds=int(seconds), microseconds=int(msus))
-        except Exception as exc:
-            warnings.warn(
-                "In a future version, `to_timedelta` will return NaT instead "
-                "of raising an exception if a value cannot be parsed.",
-                FutureWarning
+            return datetime.timedelta(
+                hours=int(hours), minutes=int(minutes),
+                seconds=int(seconds), microseconds=int(msus)
             )
-            raise exc
-    elif isinstance(x, timedelta):
+
+        except Exception as exc:
+            _logger.debug(f"Failed to parse timedelta string '{x}'",
+                          exc_info=exc)
+            return None
+
+    elif isinstance(x, datetime.timedelta):
         return x
 
+    else:
+        return None
 
-def to_datetime(x):
+
+def to_datetime(x) -> Optional[datetime.datetime]:
     """Fast datetime object creation from a date string.
 
     Permissible string formats:
@@ -183,20 +201,24 @@ def to_datetime(x):
             if '.' in seconds:
                 seconds, msus = seconds.split('.')
                 if len(msus) < 6:
-                    msus = msus+'0'*(6-len(msus))
+                    msus = msus + '0' * (6 - len(msus))
                 elif len(msus) > 6:
                     msus = msus[0:6]
             else:
                 msus = 0
 
-            return datetime(int(year), int(month), int(day), int(hours),
-                            int(minutes), int(seconds), int(msus))
-        except Exception as exc:
-            warnings.warn(
-                "In a future version, `to_datetime` will return NaT instead "
-                "of raising an exception if a value cannot be parsed.",
-                FutureWarning
+            return datetime.datetime(
+                int(year), int(month), int(day), int(hours),
+                int(minutes), int(seconds), int(msus)
             )
-            raise exc
-    elif isinstance(x, datetime):
+
+        except Exception as exc:
+            _logger.debug(f"Failed to parse datetime string '{x}'",
+                          exc_info=exc)
+            return None
+
+    elif isinstance(x, datetime.datetime):
         return x
+
+    else:
+        return None
